<!-- This file defines the DocBook-utils Style Sheet for DocBook
     Eric Bischoff <eric@caldera.de>

  Modificato per impedire la creazione della TOC per gli articoli,
  evitare l'auto-label delle sezioni ed altre buffe cose.
  I commenti alle voci modificate iniziano con 'ERLUG: '

  Per ulteriori parametri (commentati) vedere il file "dbparam.dsl"
  nella directory /usr/share/sgml/docbook/stylesheet/dsssl/modular/print/

-->

<!DOCTYPE style-sheet PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN" [
  <!ENTITY % html "IGNORE">
  <![%html; [
	<!ENTITY % print "IGNORE">
	<!ENTITY docbook.dsl PUBLIC "-//Norman Walsh//DOCUMENT DocBook HTML Stylesheet//EN" CDATA dsssl>
  ]]>
  <!ENTITY % print "INCLUDE">
  <![%print; [
	<!ENTITY docbook.dsl PUBLIC "-//Norman Walsh//DOCUMENT DocBook Print Stylesheet//EN" CDATA dsssl>
  ]]>
]>

<STYLE-SHEET>

  <STYLE-SPECIFICATION ID="UTILS" USE="DOCBOOK">
    <STYLE-SPECIFICATION-BODY>
;; ===================================================================
;; Generic Parameters
;; (Generic currently means: both print and html)

;; ERLUG: settato ad #f per impedire la numerazione automatica
;;        dei tag 'sectX'.
(define %section-autolabel% #f)
;; ERLUG: settato ad #f per impedire la generazione della TOC per i
;;        documenti 'article'.
(define %generate-article-toc% #f)

(define %chapter-autolabel% #t)

(define (toc-depth nd) 3)

    </STYLE-SPECIFICATION-BODY>
  </STYLE-SPECIFICATION>

  <STYLE-SPECIFICATION ID="PRINT" USE="UTILS">
    <STYLE-SPECIFICATION-BODY>
;; ===================================================================
;; Print Parameters
;; Call: jade -d docbook-utils.dsl#print

;; ERLUG: numero di colonne in una pagina.
;;(define %page-n-columns% 2)
;; ERLUG: spaziatura tra le colonne
;;(define %page-column-sep% 0.5in)



; === Page layout ===
;; ERLUG: pagine in formato A4
(define %paper-type% "A4")		;; use A4 paper - comment this out if needed
;; ERLUG: non generare gli ULINK per gli stampati.
;;        Altrimenti compaiono i nomi dei file nell'allegato A,
;;        accanto alle immagini.
(define %show-ulinks% #f)


; === Media objects ===
(define preferred-mediaobject-extensions  ;; this magic allows to use different graphical
   (list "eps"))			;;   formats for printing and putting online
(define acceptable-mediaobject-extensions
   '())
(define preferred-mediaobject-notations
   (list "EPS"))
(define acceptable-mediaobject-notations
   (list "linespecific"))

; === Rendering ===
(define %head-after-factor% 0.2)	;; not much whitespace after orderedlist head
(define ($paragraph$)			;; more whitespace after paragraph than before
  (make paragraph
    first-line-start-indent: (if (is-first-para)
                                 %para-indent-firstpara%
                                 %para-indent%)
    space-before: (* %para-sep% 4)
    space-after: (/ %para-sep% 4)
    quadding: %default-quadding%
    hyphenate?: %hyphenation%
    language: (dsssl-language-code)
    (process-children)))

    </STYLE-SPECIFICATION-BODY>
  </STYLE-SPECIFICATION>

  <STYLE-SPECIFICATION ID="HTML" USE="UTILS">
    <STYLE-SPECIFICATION-BODY>
;; ===================================================================
;; HTML Parameters
;; Call: jade -d docbook-utils.dsl#html

; === File names ===
(define %root-filename% "index")	;; name for the root html file
(define %html-ext% ".html")		;; default extension for html output files
(define %html-prefix% "")               ;; prefix for all filenames generated (except root)
(define %use-id-as-filename% #f)        ;; if #t uses ID value, if present, as filename
                                        ;;   otherwise a code is used to indicate level
                                        ;;   of chunk, and general element number
                                        ;;   (nth element in the document)
(define use-output-dir #f)              ;; output in separate directory?
(define %output-dir% "HTML")            ;; if output in directory, it's called HTML

; === HTML settings ===
(define %html-pubid% "-//W3C//DTD HTML 4.01 Transitional//EN") ;; Nearly true :-(
(define %html40% #t)

; === Media objects ===
(define preferred-mediaobject-extensions  ;; this magic allows to use different graphical
  (list "png" "jpg" "jpeg"))		;;   formats for printing and putting online
(define acceptable-mediaobject-extensions
  (list "bmp" "gif" "eps" "epsf" "avi" "mpg" "mpeg" "qt"))
(define preferred-mediaobject-notations
  (list "PNG" "JPG" "JPEG"))
(define acceptable-mediaobject-notations
  (list "EPS" "BMP" "GIF" "linespecific"))                                                                                                    
; === Rendering ===
(define %admon-graphics% #t)		;; use symbols for Caution|Important|Note|Tip|Warning

; === Books only ===
(define %generate-book-titlepage% #t)
(define %generate-book-toc% #t)
(define ($generate-chapter-toc$) #f)	;; never generate a chapter TOC in books

; === Articles only ===
;; ERLUG: genera il titolo in alto a dx.
(define %generate-article-titlepage% #t)
;; ERLUG: commentato: vedere il corrispondente parametro generico.
;;(define %generate-article-toc% #f)      ;; make TOC

    </STYLE-SPECIFICATION-BODY>
  </STYLE-SPECIFICATION>


  <STYLE-SPECIFICATION ID="TEXT" USE="UTILS">
    <STYLE-SPECIFICATION-BODY>
;; ===================================================================
;; TEXT Parameters
;; Call: jade -d docbook-utils.dsl#text
;; ERLUG: questa sezione e` stata introdotta per gestire la
;;        versione solo testo di 'allegato.docbook'

;; ERLUG: non si possono usare le immagini, per la versione solo testo.
(define preferred-mediaobject-extensions '())
(define acceptable-mediaobject-extensions '())
(define preferred-mediaobject-notations '())
(define acceptable-mediaobject-notations '())

    </STYLE-SPECIFICATION-BODY>
  </STYLE-SPECIFICATION>

  <EXTERNAL-SPECIFICATION ID="DOCBOOK" DOCUMENT="docbook.dsl">

</STYLE-SHEET>
